@@ -251,8 +251,9 @@ static struct list *block_find_item(struct list *s, unsigned char *str, int dire
 }
 
 
-void block_manager(struct terminal *term, void *fcp, struct session *ses)
+void block_manager(struct terminal *term, void *fcp, void *ses_)
 {
+	struct session *ses = (struct session *)ses_;
 	create_list_window(&blocks_ld, &blocks, term, ses);
 }
 
@@ -284,7 +285,7 @@ void block_url_query(struct session *ses, unsigned char *u)
 	if (test_list_window_in_use(&blocks_ld, ses->term))
 		return;
 
-	input_field(ses->term, NULL, TEXT_(T_BLOCK_URL), TEXT_(T_BLOCK_ADD), ses, 0, MAX_INPUT_URL_LEN, u, 0, 0, NULL, TEXT_(T_OK), block_url_add, TEXT_(T_CANCEL), NULL, NULL);
+	input_field(ses->term, NULL, TEXT_(T_BLOCK_URL), TEXT_(T_BLOCK_ADD), ses, 0, MAX_INPUT_URL_LEN, u, 0, 0, NULL, 2, TEXT_(T_OK), block_url_add, TEXT_(T_CANCEL), input_field_null);
 
 }
 
